@@ -232,7 +232,7 @@ def validate_semver(
     if value is None:
         return None
     try:
-        ver = semver.VersionInfo.parse(value)
+        ver = semver.VersionInfo.parse(value.lstrip("v"))
         return ver
     except ValueError as ex:
         # We do want to wrap `ex` in a new exception
@@ -356,7 +356,7 @@ def main(
 
     # Run commands.
     if install is not None:
-        _install(logger, service_account)
+        _install(str(install), logger, service_account)
     elif debug is not None:
         _debug(logger, debug)
     elif backup is not None:
@@ -398,7 +398,7 @@ def _version_check() -> None:
         wprint("This is bug, please report!", level="error")
 
 
-def _install(logger: Any, service_account: str) -> None:
+def _install(install: str, logger: Any, service_account: str) -> None:
     """Run the install command.
 
     https://www.structlog.org/en/stable/typing.html#type-hints
